hakyll-4.16.8.0: A static website compiler library
Safe HaskellNone
LanguageHaskell2010

Hakyll.Core.Dependencies

Synopsis

Documentation

data Dependency Source #

A data type representing a dependency on another Identifier. We can depend either on the Metadata or the entire content of the underlying file. This is signified by the supplied DependencyKind.

Instances

Instances details
Show Dependency Source # 
Instance details

Defined in Hakyll.Core.Dependencies

Binary Dependency Source # 
Instance details

Defined in Hakyll.Core.Dependencies

outOfDate Source #

Arguments

:: [Identifier]

All known identifiers

-> Set Identifier

Changed content

-> Set Identifier

Changed metadata

-> DependencyFacts

Old dependency facts

-> (Set Identifier, DependencyFacts, [String]) 

contentDependency :: DependencySelector -> Dependency Source #

Utility function to create a new content dependency.

metadataDependency :: DependencySelector -> Dependency Source #

Utility function to a create a new metadata dependency.