| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Hakyll.Core.Dependencies
Synopsis
- data Dependency
- data DependencySelector
- data DependencyKind
- type DependencyFacts = Map Identifier [Dependency]
- outOfDate :: [Identifier] -> Set Identifier -> Set Identifier -> DependencyFacts -> (Set Identifier, DependencyFacts, [String])
- contentDependency :: DependencySelector -> Dependency
- metadataDependency :: DependencySelector -> Dependency
Documentation
data Dependency Source #
A data type representing a dependency on another Identifier. We can
depend either on the Metadata or the entire content of
the underlying file. This is signified by the supplied DependencyKind.
Constructors
| Dependency DependencyKind DependencySelector | |
| AlwaysOutOfDate |
Instances
| Show Dependency Source # | |
Defined in Hakyll.Core.Dependencies Methods showsPrec :: Int -> Dependency -> ShowS # show :: Dependency -> String # showList :: [Dependency] -> ShowS # | |
| Binary Dependency Source # | |
Defined in Hakyll.Core.Dependencies | |
data DependencySelector Source #
Constructors
| PatternDependency Pattern (Set Identifier) | |
| IdentifierDependency Identifier |
Instances
| Show DependencySelector Source # | |
Defined in Hakyll.Core.Dependencies Methods showsPrec :: Int -> DependencySelector -> ShowS # show :: DependencySelector -> String # showList :: [DependencySelector] -> ShowS # | |
| Binary DependencySelector Source # | |
Defined in Hakyll.Core.Dependencies Methods put :: DependencySelector -> Put # get :: Get DependencySelector # putList :: [DependencySelector] -> Put # | |
data DependencyKind Source #
Constructors
| KindContent | |
| KindMetadata |
Instances
| Show DependencyKind Source # | |
Defined in Hakyll.Core.Dependencies Methods showsPrec :: Int -> DependencyKind -> ShowS # show :: DependencyKind -> String # showList :: [DependencyKind] -> ShowS # | |
| Binary DependencyKind Source # | |
Defined in Hakyll.Core.Dependencies Methods put :: DependencyKind -> Put # get :: Get DependencyKind # putList :: [DependencyKind] -> Put # | |
type DependencyFacts = Map Identifier [Dependency] Source #
Arguments
| :: [Identifier] | All known identifiers |
| -> Set Identifier | Changed content |
| -> Set Identifier | Changed metadata |
| -> DependencyFacts | Old dependency facts |
| -> (Set Identifier, DependencyFacts, [String]) |
contentDependency :: DependencySelector -> Dependency Source #
Utility function to create a new content dependency.
metadataDependency :: DependencySelector -> Dependency Source #
Utility function to a create a new metadata dependency.